==> betterthanbread-0.5.2-beta-sources.jar: iced/betterthanbread/items/ModFoodComponent.java <==
package iced.betterthanbread.items;

import net.minecraft.class_1293;
import net.minecraft.class_1294;
import net.minecraft.class_4174;

public class ModFoodComponent {
    //public static FoodComponent DOUGH = new FoodComponent.Builder().hunger(1).saturationModifier(0.25f).build();

    // Kids, don't eat raw dough
    public static class_4174 RAW_CINNAMON_ROLL_DOUGH = new class_4174.class_4175()
            .method_19238(3)
            .method_19237(0.35f)
            .method_19239(new class_1293(class_1294.field_5903, 600), 1)
            .method_19240()
            .method_19242();

    public static class_4174 RAW_CINNAMON_ROLL = new class_4174.class_4175()
            .method_19238(1)
            .method_19237(0.25f)
            .method_19239(new class_1293(class_1294.field_5903, 600), 1)
            .method_19240()
            .method_19242();

    public static class_4174 CINNAMON_ROLL = new class_4174.class_4175()
            .method_19238(4)
            .method_19237(0.5f)
            .method_19242();

    public static class_4174 GLAZED_CINNAMON_ROLL = new class_4174.class_4175()
            .method_19238(5)
            .method_19237(0.55f)
            .method_19242();

    public static class_4174 BUTTER = new class_4174.class_4175()
            .method_19238(1)
            .method_19237(0.5f)
            .method_19242();

    public static class_4174 SAUSAGE = new class_4174.class_4175()
            .method_19238(4)
            .method_19237(0.5f)
            .method_19242();

    public static class_4174 RAW_SAUSAGE = new class_4174.class_4175()
            .method_19238(2)
            .method_19237(0.25f)
            .method_19239(new class_1293(class_1294.field_5916, 600), 1)
            .method_19239(new class_1293(class_1294.field_5899, 600), 1)
            .method_19242();

    public static class_4174 RAW_CROISSANT = new class_4174.class_4175()
            .method_19238(1)
            .method_19237(0.25f)
            .method_19239(new class_1293(class_1294.field_5903, 600), 1)
            .method_19240()
            .method_19242();

    public static class_4174 CROISSANT = new class_4174.class_4175()
            .method_19238(5)
            .method_19237(0.5f)
            .method_19242();
}

==> betterthanbread-0.7.0-beta-sources.jar: iced/betterthanbread/items/ModFoodComponent.java <==
package iced.betterthanbread.items;

import net.minecraft.class_1293;
import net.minecraft.class_1294;
import net.minecraft.class_4174;

public class ModFoodComponent {
    //public static FoodComponent DOUGH = new FoodComponent.Builder().hunger(1).saturationModifier(0.25f).build();

    // Kids, don't eat raw dough
    public static class_4174 RAW_CINNAMON_ROLL_DOUGH = new class_4174.class_4175()
            .method_19238(3)
            .method_19237(0.35f)
            .method_19239(new class_1293(class_1294.field_5903, 600), 1)
            .method_19240()
            .method_19242();

    public static class_4174 RAW_CINNAMON_ROLL = new class_4174.class_4175()
            .method_19238(1)
            .method_19237(0.25f)
            .method_19239(new class_1293(class_1294.field_5903, 600), 1)
            .method_19240()
            .method_19242();

    public static class_4174 CINNAMON_ROLL = new class_4174.class_4175()
            .method_19238(4)
            .method_19237(0.5f)
            .method_19242();

    public static class_4174 GLAZED_CINNAMON_ROLL = new class_4174.class_4175()
            .method_19238(5)
            .method_19237(0.55f)
            .method_19242();

    public static class_4174 BUTTER = new class_4174.class_4175()
            .method_19238(1)
            .method_19237(0.5f)
            .method_19242();

    public static class_4174 SAUSAGE = new class_4174.class_4175()
            .method_19238(4)
            .method_19237(0.5f)
            .method_19242();

    public static class_4174 RAW_SAUSAGE = new class_4174.class_4175()
            .method_19238(2)
            .method_19237(0.25f)
            .method_19239(new class_1293(class_1294.field_5916, 600), 1)
            .method_19239(new class_1293(class_1294.field_5899, 600), 1)
            .method_19242();

    public static class_4174 RAW_CROISSANT = new class_4174.class_4175()
            .method_19238(1)
            .method_19237(0.25f)
            .method_19239(new class_1293(class_1294.field_5903, 600), 1)
            .method_19240()
            .method_19242();

    public static class_4174 CROISSANT = new class_4174.class_4175()
            .method_19238(5)
            .method_19237(0.5f)
            .method_19242();

    public static class_4174 RAW_PAIN_AU_CHOCOLAT = new class_4174.class_4175()
            .method_19238(1)
            .method_19237(0.25f)
            .method_19239(new class_1293(class_1294.field_5903, 600), 1)
            .method_19240()
            .method_19242();

    public static class_4174 PAIN_AU_CHOCOLAT = new class_4174.class_4175()
            .method_19238(1)
            .method_19237(0.5f)
            .method_19242();
}
